# Changelog

<!--next-version-placeholder-->

## v1.0.4 (2022-03-20)
### Fix
* Always get alt or do nothing ([`53987eb`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/53987eb9ce8d72961d7b7fee3bdc444acdc32f41))
* Fix blog build if alt not found in link ([`3c51807`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/3c5180775fdf3bc9306806c7786600b939feffd2))
* Revert files error ([`1065c1a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/1065c1a7c98b19e3b7b6fcf36878271013b6e993))
* Fix requirements & build because of the new https change ([`674b6df`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/674b6df4e5e05bf038f969dbaf31f95ab624f39c))

### Documentation
* **readme:** Add demo gif ([`c13137d`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/c13137dbf59ac9874ca911c555870101c4c7b7fb))

## v1.0.3 (2022-01-20)
### Fix
* Adjust link generation ([`001d6e9`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/001d6e92a4f6556004382bb841b3b13c298dfda6))

### Documentation
* **gitignore:** Exclude build ([`80da76b`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/80da76b7f2f2433a154db5b41aed522de197e0bc))

## v1.0.2 (2022-01-20)
### Fix
* **extension:** Add extension to parse markdown in embed files ([`5dfac7a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/5dfac7a793cb03c27ebd406db42042f413c2ae32))

### Documentation
* **readme:** Update readme ([`84dc575`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/84dc575bce22560f69fbdb7e8d00f2f92ca0f222))
* **readme:** Fix typo ([`a48b56a`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/a48b56a855dafca67172d120b14036e9ede1745d))
* **readme:** Add screenshot ([`307fbb1`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/307fbb12cb87ec6cdefac4b6bf9dfb737b399e1d))

## v1.0.1 (2022-01-20)
### Fix
* Fix all contents citation ([`a5a21b6`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/a5a21b6efda0b44c09aa9b16d5db4c9106c2780b))

## v1.0.0 (2022-01-20)
### Feature
* **commit:** First commit ([`0ef98d3`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/0ef98d3b1141c8a05a03133fd764de2160b0a288))

### Breaking
* First commit ([`0ef98d3`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/0ef98d3b1141c8a05a03133fd764de2160b0a288))

### Documentation
* **css:** Add css example ([`85ceba1`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/85ceba1ae6240b016f7947790ab41d7cafae6f85))
* **gitignore:** Add idea and test ([`d1d3e83`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/d1d3e83954491b962c9736f6fca35ea31c2bc7c0))
* **readme:** Add readme ([`28d395f`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/28d395f76f27ccc2a0de10c0d96f00cf16ceac35))
* **readme:** Update readme ([`04fee26`](https://github.com/Mara-Li/mkdocs_embed_file_plugins/commit/04fee26e291f30337e5e3af52aa3b400cfbf1d0a))
